#include <iostream>
#include <Eigen/Eigen>

#include "levenberg_marquardt.h"

struct SimpleFunctor {
	typedef Eigen::Vector2d ParameterVector;
	typedef Eigen::Vector2d ResidualVector;

	template<class FLOAT>
	void operator()( const FLOAT* const input, FLOAT* output ) const {
		output[0] = FLOAT(1.0) - input[0];
		output[1] = FLOAT(2.0) - input[1];
	}
};


int main( int argc, char** argv ) {
	google::ParseCommandLineFlags( &argc, &argv, true );
	google::InitGoogleLogging( argv[0] );

	SimpleFunctor functor;

	Eigen::Vector2d x;
	x << 5.0, 3.0;

	libmv::LevenbergMarquardt<SimpleFunctor>::SolverParameters solverParams;
	libmv::LevenbergMarquardt<SimpleFunctor> solver( functor );
	solver.minimize( solverParams, &x );

	std::cout << x << std::endl;

	return 0;
}
